@@ -219,6 +219,19 @@ class arg(Argument):
         """
         return arg(*args, group=group, help=help, dest=dest, action='store_false' if off else 'store_true')
 
+    @staticmethod
+    def binary(
+        *args: str,
+        help : Union[omit, str] = omit,
+        dest : Union[omit, str] = omit,
+        metavar : Optional[str] = None,
+        group: Optional[str] = None,
+    ) -> Argument:
+        """
+        Used to add argparse arguments that contain binary data.
+        """
+        return arg(*args, group=group, help=help, dest=dest, type=multibin, metavar=metavar or 'B')
+
     @staticmethod
     def number(
         *args: str,
@@ -436,7 +449,6 @@ def UnitProcessorBoilerplate(
 ) -> Callable[[ByteString], Any]:
     @wraps(operation)
     def wrapped(self, data: ByteString) -> Union[Optional[ByteString], Iterable[ByteString]]:
-        data = self.args @ data
         typespec = get_type_hints(operation)
         typespec.pop('return', None)
         if typespec:
@@ -444,10 +456,10 @@ def UnitProcessorBoilerplate(
             dt = next(iter(typespec.values()))
             if isinstance(dt, type) and not isinstance(data, dt):
                 data = dt(data)
-        if wrapped.chunked:
-            return (self.labelled(r) for r in operation(self, data))
-        return self.labelled(operation(self, data))
-    wrapped.chunked = inspect.isgeneratorfunction(operation)
+        result = operation(self, data)
+        if not inspect.isgenerator(result):
+            return self.labelled(result)
+        return (self.labelled(r) for r in result)
     return wrapped
 
 
@@ -617,20 +629,31 @@ class Executable(type):
     def __ror__(cls, other):
         return cls().__ror__(other)
 
+    @property
+    def is_multiplex(cls) -> bool:
+        """
+        This proprety is `True` if and only if the unit's `process` or `reverse` method is a generator, i.e.
+        when the unit can generate multiple outputs.
+        """
+        if inspect.isgeneratorfunction(inspect.unwrap(cls.process)):
+            return True
+        if not cls.is_reversible:
+            return False
+        return inspect.isgeneratorfunction(inspect.unwrap(cls.reverse))
+
     @property
     def is_reversible(cls) -> bool:
         """
-        This property is `True` if and only if the unit has a member function
-        named `reverse`. By convention, this member function implements the
-        inverse of `refinery.units.Unit.process`.
+        This property is `True` if and only if the unit has a member function named `reverse`. By convention,
+        this member function implements the inverse of `refinery.units.Unit.process`.
         """
         return hasattr(cls, 'reverse')
 
     @property
     def codec(cls) -> str:
         """
-        The default codec for encoding textual information between units.
-        The value of this property is hardcoded to `UTF8`.
+        The default codec for encoding textual information between units. The value of this property is
+        hardcoded to `UTF8`.
         """
         return 'UTF8'
 
@@ -833,11 +856,9 @@ class Unit(metaclass=Executable, abstract=True):
         if self._framed:
             return self._framed
 
-        op = self.reverse if self.args.reverse else self.process
-
         def normalized_action(data: ByteString) -> Iterable[ByteString]:
             try:
-                result = op(data)
+                result = self.act(data)
                 if inspect.isgenerator(result):
                     yield from filter(lambda x: x is not None, result)
                 elif result is not None:
@@ -1000,7 +1021,7 @@ class Unit(metaclass=Executable, abstract=True):
 
     def act(self, data: Union[Chunk, ByteString]) -> Union[ByteString, Chunk, None]:
         op = self.reverse if self.args.reverse else self.process
-        return op(data)
+        return op(self.args @ data)
 
     def __call__(self, data: Union[ByteString, Chunk, None] = None) -> bytes:
         with MemoryFile(data) if data else open(os.devnull, 'rb') as stdin:
@@ -1106,7 +1127,7 @@ class Unit(metaclass=Executable, abstract=True):
         if cls.is_reversible:
             base.add_argument('-R', '--reverse', action='store_true', help='Use the reverse operation.')
 
-        if cls.process.chunked or (cls.is_reversible and cls.reverse.chunked):
+        if cls.is_multiplex:
             base.add_argument('-Z', '--squeeze', action='store_true', help='Fuse outputs, do not insert line breaks.')
 
         base.add_argument('-Q', '--quiet', action='store_true', help='Disables all log output.')
