@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from . import JSONEncoderUnit
+from . import arg, JSONEncoderUnit
 from .....lib.dotnet.header import DotNetHeader
 
 
@@ -9,15 +9,12 @@ class dnhdr(JSONEncoderUnit):
     Expects data that has been formatted with the `BinaryFormatter` class. The
     output is a representation of the deserialized data in JSON format.
     """
-
-    @classmethod
-    def interface(cls, argp):
-        argp.add_argument(
-            '-r', '--resources',
-            action='store_true',
-            help='also parse resources'
-        )
-        return super().interface(argp)
+    def __init__(
+        self,
+        resources: arg.switch('-r', '--resources', help='Also parse .NET resources.') = False,
+        encode=None, digest=None
+    ):
+        super().__init__(encode=encode, digest=digest, resources=resources)
 
     def process(self, data):
         dn = DotNetHeader(data, parse_resources=self.args.resources)
