@@ -5,7 +5,7 @@ import textwrap
 
 from . import arg, HexViewer, get_terminal_size
 from ...lib.types import INF
-from ...lib.tools import entropy
+from ...lib.tools import entropy, isbuffer
 
 
 class peek(HexViewer):
@@ -37,6 +37,31 @@ class peek(HexViewer):
             self.log_info('forwarding input to next unit')
             yield data
 
+    def _peekmeta(self, data, linewidth, sep):
+        try:
+            meta = data.meta
+        except AttributeError:
+            return
+        if not meta:
+            return
+        width = max(len(name) for name in data.meta)
+        if not self.args.brief:
+            yield sep
+        for name, value in data.meta.items():
+            if isbuffer(value):
+                try:
+                    decoded: str = value.decode(self.codec)
+                    assert decoded.isprintable()
+                except UnicodeDecodeError:
+                    decoded = None
+                except AssertionError:
+                    decoded = None
+                value = decoded or F'H:{value.hex()}'
+            metavar = F'{name:>{width}} : {value!s}'
+            if len(metavar) > linewidth:
+                metavar = metavar[:linewidth - 3] + '...'
+            yield metavar
+
     def _peeklines(self, data):
         import codecs
         import string
@@ -111,8 +136,10 @@ class peek(HexViewer):
         else:
             yield header
 
+        yield from self._peekmeta(data, width, separator())
+
         if dump:
-            yield separator(F'CODEC={working_codec}' if working_codec else 'HEXDUMP')
+            yield separator(F'CODEC={working_codec}' if working_codec else None)
             yield from dump
 
         if self.separate:
